@@ -20,6 +20,10 @@ public:
 
 CLocalPath FZCUI_PUBLIC_SYMBOL GetUnadjustedSettingsDir();
 
+#if FZ_WINDOWS
+std::wstring FZCUI_PUBLIC_SYMBOL GetOwnExecutable();
+#endif
+
 // If non-empty, always terminated by a separator
 std::wstring FZCUI_PUBLIC_SYMBOL GetOwnExecutableDir();
 
