@@ -52,6 +52,14 @@ public:
 			int64_t size{};
 			fz::datetime time;
 			int attributes{};
+
+			enum : uint8_t {
+				flag_dir = 0x1u,
+				flag_link = 0x2u
+			};
+			uint8_t flags{};
+			bool is_dir() const { return flags & flag_dir; }
+			bool is_link() const { return flags & flag_link; }
 		};
 
 		std::vector<entry> files;
