@@ -4,7 +4,7 @@
 #include "filter.h"
 #include "site.h"
 
-class FZC_PUBLIC_SYMBOL recursive_operation
+class FZCUI_PUBLIC_SYMBOL recursive_operation
 {
 public:
 	virtual ~recursive_operation() = default;
