@@ -8,11 +8,7 @@
   #define FZCUI_PUBLIC_SYMBOL FZ_EXPORT_PUBLIC
   #define FZCUI_PRIVATE_SYMBOL FZ_EXPORT_PRIVATE
 #else
-  #if FZCUI_USING_DLL
-    #define FZCUI_PUBLIC_SYMBOL FZ_IMPORT_SHARED
-  #else
-    #define FZCUI_PUBLIC_SYMBOL FZ_IMPORT_STATIC
-  #endif
+  #define FZCUI_PUBLIC_SYMBOL FZ_IMPORT_SHARED
   #define FZCUI_PRIVATE_SYMBOL
 #endif
 
