@@ -1,4 +1,6 @@
 #include "xml_file.h"
+#include "buildinfo.h"
+
 #include "../include/version.h"
 
 #include <libfilezilla/file.hpp>
@@ -488,8 +490,8 @@ bool GetServer(pugi::xml_node node, Site & site)
 		site.server.SetPasvMode(MODE_DEFAULT);
 	}
 
-	int maximumMultipleConnections = GetTextElementInt(node, "MaximumMultipleConnections");
-	site.server.MaximumMultipleConnections(maximumMultipleConnections);
+	auto maximumMultipleConnections = GetTextElementInt(node, "MaximumMultipleConnections");
+	site.connection_limit_ = static_cast<unsigned int>(maximumMultipleConnections);
 
 	std::string_view encodingType = node.child_value("EncodingType");
 	if (encodingType == "UTF-8") {
