@@ -4,6 +4,7 @@
 #include "../include/engine_context.h"
 #include "../include/engine_options.h"
 #include "../include/logfile_writer.h"
+#include "../include/sizeformatting.h"
 
 #include "directorycache.h"
 #include "logging_private.h"
@@ -93,6 +94,7 @@ public:
 		, rate_limit_mgr_(loop_)
 		, tlsSystemTrustStore_(pool_)
 		, logfile_writer_(options_, loop_)
+	    , size_formatter_(options_)
 	{
 		directory_cache_.SetTtl(fz::duration::from_seconds(options.get_int(OPTION_CACHE_TTL)));
 		rate_limit_mgr_.add(&rate_limiter_);
@@ -114,6 +116,7 @@ public:
 	fz::tls_system_trust_store tlsSystemTrustStore_;
 	activity_logger activity_logger_;
 	logfile_writer logfile_writer_;
+	SizeFormatter size_formatter_;
 };
 
 CFileZillaEngineContext::CFileZillaEngineContext(COptionsBase & options, CustomEncodingConverterBase const& customEncodingConverter)
@@ -171,3 +174,8 @@ logfile_writer & CFileZillaEngineContext::GetLogFileWriter()
 {
 	return impl_->logfile_writer_;
 }
+
+SizeFormatter & CFileZillaEngineContext::size_formatter()
+{
+	return impl_->size_formatter_;
+}
