@@ -307,9 +307,9 @@ bool CFtpRawTransferOpData::ParseEpsvResponse()
 	}
 
 	std::wstring number = controlSocket_.m_Response.substr(pos + 4, pos2 - pos - 4);
-	auto port = fz::to_integral<unsigned int>(number);
+	auto port = fz::to_integral<unsigned short>(number);
 
-	if (port == 0 || port > 65535) {
+	if (!port) {
 		return false;
 	}
 
