@@ -3,18 +3,20 @@
 
 #include "ftpcontrolsocket.h"
 
-enum rawtransferStates
+namespace FtpRawTransferStates {
+enum type
 {
-	rawtransfer_init = 0,
-	rawtransfer_type,
-	rawtransfer_port_pasv,
-	rawtransfer_rest,
-	rawtransfer_transfer,
-	rawtransfer_waitfinish,
-	rawtransfer_waittransferpre,
-	rawtransfer_waittransfer,
-	rawtransfer_waitsocket
+        rawtransfer_init = 0,
+        rawtransfer_type,
+        rawtransfer_port_pasv,
+        rawtransfer_rest,
+        rawtransfer_transfer,
+        rawtransfer_waitfinish,
+        rawtransfer_waittransferpre,
+        rawtransfer_waittransfer,
+        rawtransfer_waitsocket
 };
+}
 
 class CFtpRawTransferOpData final : public COpData, public CFtpOpData
 {
