@@ -3,6 +3,8 @@
 
 #include "../controlsocket.h"
 
+#include <optional>
+
 class CFileZillaEnginePrivate;
 class CFtpControlSocket;
 class CDirectoryListingParser;
@@ -47,6 +49,8 @@ public:
 	void ContinueWithoutSesssionResumption();
 
 protected:
+	bool DoSetupPassiveTransfer();
+
 	bool CheckGetNextWriteBuffer();
 	bool CheckGetNextReadBuffer();
 	void FinalizeWrite();
@@ -89,6 +93,13 @@ protected:
 	bool m_postponedSend{};
 	void TriggerPostponedEvents();
 
+	struct passive_mode_data {
+		std::string host_;
+		uint16_t port_{};
+		uint16_t attempts_;
+	};
+	std::optional<passive_mode_data> passive_mode_data_;
+
 	std::unique_ptr<fz::socket> socket_;
 	std::unique_ptr<activity_logger_layer> activity_logger_layer_;
 	std::unique_ptr<fz::rate_limited_layer> ratelimit_layer_;
