@@ -15,8 +15,10 @@
 #include <libfilezilla/local_filesys.hpp>
 #include <libfilezilla/uri.hpp>
 
+using namespace std::literals;
+
 http_client::http_client(CHttpControlSocket & controlSocket)
-	: fz::http::client::client(controlSocket, *controlSocket.buffer_pool_, controlSocket.logger(), fz::replaced_substrings(PACKAGE_STRING, " ", "/"))
+    : fz::http::client::client(controlSocket, *controlSocket.buffer_pool_, controlSocket.logger(), "FileZilla/"s + ENGINE_VERSION)
 	, controlSocket_(controlSocket)
 {
 }
