@@ -2,6 +2,7 @@
 #include "../include/local_path.h"
 
 #include <libfilezilla/format.hpp>
+#include <libfilezilla/local_filesys.hpp>
 
 #ifndef FZ_WINDOWS
 #include <errno.h>
@@ -415,8 +416,11 @@ bool CLocalPath::ChangePath(std::wstring const& new_path, std::wstring* file)
 #endif
 }
 
-bool CLocalPath::Exists(std::wstring *error) const
+bool CLocalPath::Exists(std::wstring *error, bool * is_link) const
 {
+	if (is_link) {
+		*is_link = false;
+	}
 	if (m_path->empty()) {
 		if (error) {
 			*error = _("No path given");
@@ -481,6 +485,13 @@ bool CLocalPath::Exists(std::wstring *error) const
 		return false;
 	}
 
+	if (is_link) {
+		if (ret & FILE_ATTRIBUTE_REPARSE_POINT) {
+			*is_link = fz::local_filesys::get_file_type(path, false) == fz::local_filesys::link;
+		}
+	}
+
+
 	return true;
 #else
 	std::string path = fz::to_string(*m_path);
@@ -489,7 +500,15 @@ bool CLocalPath::Exists(std::wstring *error) const
 	}
 
 	struct stat buf;
-	int result = stat(path.c_str(), &buf);
+	int result = lstat(path.c_str(), &buf);
+#ifdef S_ISLNK
+	if (!result) {
+		if (is_link && S_ISLNK(buf.st_mode)) {
+			*is_link = true;
+			result = stat(path.c_str(), &buf);
+		}
+	}
+#endif
 
 	if (!result) {
 		if (S_ISDIR(buf.st_mode)) {
