@@ -1,4 +1,4 @@
-#include <filezilla.h>
+#include "filezilla.h"
 #include "engineprivate.h"
 #include "proxy.h"
 #include "controlsocket.h"
@@ -7,6 +7,7 @@
 
 #include <algorithm>
 
+#include <assert.h>
 #include <string.h>
 
 enum handshake_state
@@ -36,6 +37,7 @@ CProxySocket::CProxySocket(fz::event_handler* pEvtHandler, fz::socket_interface
 CProxySocket::~CProxySocket()
 {
 	remove_handler();
+	next_layer_.set_event_handler(nullptr);
 }
 
 std::wstring CProxySocket::Name(ProxyType t)
@@ -105,11 +107,11 @@ int CProxySocket::connect(fz::native_string const& host, unsigned int port, fz::
 
 		// Bit oversized, but be on the safe side
 		std::string host_raw = fz::to_utf8(host);
-		sendBuffer_.append(fz::sprintf("CONNECT %s:%u HTTP/1.1\r\nHost: %s:%u\r\n%sUser-Agent: %s\r\n\r\n",
+		sendBuffer_.append(fz::sprintf("CONNECT %s:%u HTTP/1.1\r\nHost: %s:%u\r\n%sUser-Agent: FileZilla/\r\n\r\n",
 			host_raw, port,
 			host_raw, port,
 			auth,
-			fz::replaced_substrings(PACKAGE_STRING, " ", "/")));
+		    ENGINE_VERSION));
 	}
 	else if (type_ == ProxyType::SOCKS4) {
 		std::string ip;
@@ -214,6 +216,7 @@ void CProxySocket::OnSocketEvent(socket_event_source* s, fz::socket_event_flag t
 	switch (t) {
 	case fz::socket_event_flag::connection:
 		m_pOwner->log(logmsg::status, _("Connection with proxy established, performing handshake..."));
+		OnSend();
 		break;
 	case fz::socket_event_flag::read:
 		OnReceive();
