@@ -5,10 +5,6 @@
 #include "config.h"
 #endif
 
-#ifndef PACKAGE_STRING
-#define PACKAGE_STRING "FileZilla 3"
-#endif
-
 #include <libfilezilla/libfilezilla.hpp>
 
 #include "setup.h"
