@@ -243,7 +243,7 @@ CLocalTreeView::CLocalTreeView(wxWindow* parent, wxWindowID id, CState& state, C
 	, CStateEventHandler(state)
 	, COptionChangeEventHandler(this)
 	, m_pQueueView(pQueueView)
-    , options_(options)
+	, options_(options)
 {
 	wxGetApp().AddStartupProfileRecord("CLocalTreeView::CLocalTreeView"sv);
 #ifdef __WXMAC__
@@ -295,7 +295,7 @@ CLocalTreeView::~CLocalTreeView()
 
 void CLocalTreeView::SetDir(wxString const& localDir)
 {
-	if (m_currentDir == localDir) {
+	if (m_currentDir == localDir && !changing_dir_) {
 		RefreshListing();
 		return;
 	}
@@ -485,14 +485,14 @@ void CLocalTreeView::DisplayDir(wxTreeItemId parent, std::wstring const& dirname
 	bool matchedKnown = false;
 
 	fz::native_string file;
-	bool wasLink{};
+	bool was_link{};
 	int attributes{};
 	fz::local_filesys::type t{};
 	static int64_t const size(-1);
 	fz::datetime date;
 
 	wxTreeItemId last;
-	while (local_filesys.get_next_file(file, wasLink, t, 0, &date, &attributes)) {
+	while (local_filesys.get_next_file(file, was_link, t, 0, &date, &attributes)) {
 		std::wstring wfile = fz::to_wstring(file);
 		if (file.empty() || wfile.empty()) {
 			wxGetApp().DisplayEncodingWarning();
@@ -514,13 +514,18 @@ void CLocalTreeView::DisplayDir(wxTreeItemId parent, std::wstring const& dirname
 			matchedKnown = true;
 		}
 
-		last = InsertItem(parent, last, wfile, GetIconIndex(iconType::dir, fullName),
+		last = InsertItem(parent, last, wfile, GetIconIndex(iconType::dir, fullName, true, was_link),
 #ifdef __WXMSW__
 				-1
 #else
-				GetIconIndex(iconType::opened_dir, fullName)
+				GetIconIndex(iconType::opened_dir, fullName, true, was_link)
 #endif
 			);
+#if FZ_WINDOWS
+		if (was_link) {
+			TreeView_SetItemState(GetHWND(), reinterpret_cast<HTREEITEM>(last.GetID()), INDEXTOOVERLAYMASK(GetLinkOverlayIndex()), TVIS_OVERLAYMASK);
+		}
+#endif
 
 		CheckSubdirStatus(last, fullName);
 	}
@@ -553,12 +558,12 @@ std::wstring CLocalTreeView::HasSubdir(std::wstring const& dirname)
 	}
 
 	fz::native_string file;
-	bool wasLink{};
+	bool was_link{};
 	int attributes{};
 	fz::local_filesys::type t{};
 	static int64_t const size(-1);
 	fz::datetime date;
-	while (local_filesys.get_next_file(file, wasLink, t, 0, &date, &attributes)) {
+	while (local_filesys.get_next_file(file, was_link, t, 0, &date, &attributes)) {
 
 		std::wstring wfile = fz::to_wstring(file);
 		if (file.empty() || wfile.empty()) {
@@ -774,7 +779,7 @@ void CLocalTreeView::RefreshListing()
 		}
 
 		// Step 2: Enumerate subdirectories on disk and sort them
-		std::vector<std::wstring> dirs;
+		std::vector<std::pair<std::wstring, bool>> dirs;
 
 		fz::native_string file;
 		static int64_t const size(-1);
@@ -793,9 +798,9 @@ void CLocalTreeView::RefreshListing()
 				continue;
 			}
 
-			dirs.emplace_back(std::move(wfile));
+			dirs.emplace_back(std::move(wfile), was_link);
 		}
-		std::sort(dirs.begin(), dirs.end(), [&](auto const& lhs, auto const& rhs) { return sortFunction_(lhs, rhs) < 0; });
+		std::sort(dirs.begin(), dirs.end(), [&](auto const& lhs, auto const& rhs) { return sortFunction_(lhs.first, rhs.first) < 0; });
 
 		// Step 3: Merge list of subdirectories with subtree.
 		std::vector<wxTreeItemId> toDelete;
@@ -810,7 +815,7 @@ void CLocalTreeView::RefreshListing()
 			int cmp;
 			if (child && iter != dirs.end()) {
 				wxString const& childName = GetItemText(child);
-				cmp = sortFunction_(*iter, std::wstring_view(childName.data(), childName.size()));
+				cmp = sortFunction_(iter->first, std::wstring_view(childName.data(), childName.size()));
 			}
 			else if (child) {
 				cmp = 1;
@@ -822,7 +827,7 @@ void CLocalTreeView::RefreshListing()
 			if (!cmp) {
 				// Found item with same name. Mark it for further processing
 				if (!IsExpanded(child)) {
-					std::wstring path = dir.dir + *iter + separator;
+					std::wstring path = dir.dir + iter->first + separator;
 					if (!CheckSubdirStatus(child, path)) {
 						t_dir subdir;
 						subdir.dir = path;
@@ -832,7 +837,7 @@ void CLocalTreeView::RefreshListing()
 				}
 				else {
 					t_dir subdir;
-					subdir.dir = dir.dir + *iter + separator;
+					subdir.dir = dir.dir + iter->first + separator;
 					subdir.item = child;
 					dirsToCheck.push_front(subdir);
 				}
@@ -860,15 +865,21 @@ void CLocalTreeView::RefreshListing()
 			}
 			else if (cmp < 0) {
 				// New subdirectory, add treeitem
-				std::wstring fullname = dir.dir + *iter + separator;
-				last = InsertItem(dir.item, last, *iter, GetIconIndex(iconType::dir, fullname),
+				std::wstring fullname = dir.dir + iter->first + separator;
+				last = InsertItem(dir.item, last, iter->first, GetIconIndex(iconType::dir, fullname, true, iter->second),
 #ifdef __WXMSW__
 						-1
 #else
-						GetIconIndex(iconType::opened_dir, fullname)
+						GetIconIndex(iconType::opened_dir, fullname, true, iter->second)
 #endif
 					);
 
+#if FZ_WINDOWS
+				if (was_link) {
+					TreeView_SetItemState(GetHWND(), reinterpret_cast<HTREEITEM>(last.GetID()), INDEXTOOVERLAYMASK(GetLinkOverlayIndex()), TVIS_OVERLAYMASK);
+				}
+#endif
+
 				if (!firstInserted) {
 					firstInserted = last;
 				}
@@ -905,6 +916,7 @@ void CLocalTreeView::OnSelectionChanged(wxTreeEvent& event)
 	std::wstring dir = GetDirFromItem(item);
 
 	std::wstring error;
+	changing_dir_ = true;
 	if (!m_state.SetLocalDir(dir, &error)) {
 		if (!error.empty()) {
 			wxMessageBoxEx(error, _("Failed to change directory"), wxICON_INFORMATION);
@@ -916,6 +928,7 @@ void CLocalTreeView::OnSelectionChanged(wxTreeEvent& event)
 		SelectItem(event.GetOldItem());
 		--m_setSelection;
 	}
+	changing_dir_ = false;
 }
 
 void CLocalTreeView::OnStateChange(t_statechange_notifications notification, std::wstring const&, const void*)
@@ -1489,15 +1502,15 @@ bool CLocalTreeView::CheckSubdirStatus(wxTreeItemId& item, std::wstring const& p
 
 		CTreeItemData* pData = (CTreeItemData*)GetItemData(child);
 		if (pData) {
-			bool wasLink;
+			bool was_link;
 			int attributes;
 			fz::local_filesys::type type;
 			fz::datetime date;
 			if (!path.empty() && path.back() == fz::local_filesys::path_separator) {
-				type = fz::local_filesys::get_file_info(fz::to_native(path + pData->m_known_subdir), wasLink, 0, &date, &attributes);
+				type = fz::local_filesys::get_file_info(fz::to_native(path + pData->m_known_subdir), was_link, 0, &date, &attributes);
 			}
 			else {
-				type = fz::local_filesys::get_file_info(fz::to_native(path + fz::local_filesys::path_separator + pData->m_known_subdir), wasLink, 0, &date, &attributes);
+				type = fz::local_filesys::get_file_info(fz::to_native(path + fz::local_filesys::path_separator + pData->m_known_subdir), was_link, 0, &date, &attributes);
 			}
 			if (type == fz::local_filesys::dir) {
 				CFilterManager filter;
