@@ -3,6 +3,7 @@
 #include "filezillaapp.h"
 #include "sitemanager.h"
 #include "state.h"
+#include "textctrlex.h"
 #include "themeprovider.h"
 #include "treectrlex.h"
 #include "xmlfunctions.h"
@@ -11,13 +12,9 @@
 #include "../commonui/ipcmutex.h"
 
 #include <wx/dirdlg.h>
+#include <wx/statbox.h>
 #include <wx/statline.h>
 
-BEGIN_EVENT_TABLE(CNewBookmarkDialog, wxDialogEx)
-EVT_BUTTON(XRCID("wxID_OK"), CNewBookmarkDialog::OnOK)
-EVT_BUTTON(XRCID("ID_BROWSE"), CNewBookmarkDialog::OnBrowse)
-END_EVENT_TABLE()
-
 BEGIN_EVENT_TABLE(CBookmarksDialog, wxDialogEx)
 EVT_TREE_SEL_CHANGING(XRCID("ID_TREE"), CBookmarksDialog::OnSelChanging)
 EVT_TREE_SEL_CHANGED(XRCID("ID_TREE"), CBookmarksDialog::OnSelChanged)
@@ -31,44 +28,104 @@ EVT_TREE_BEGIN_LABEL_EDIT(XRCID("ID_TREE"), CBookmarksDialog::OnBeginLabelEdit)
 EVT_TREE_END_LABEL_EDIT(XRCID("ID_TREE"), CBookmarksDialog::OnEndLabelEdit)
 END_EVENT_TABLE()
 
+struct CNewBookmarkDialog::impl
+{
+	wxRadioButton* global_{};
+	wxRadioButton* specific_{};
+	wxTextCtrlEx* name_{};
+	wxTextCtrlEx* local_path_{};
+	wxTextCtrlEx* remote_path_{};
+	wxCheckBox* sync_browse_{};
+	wxCheckBox* comparison_{};
+};
+
 CNewBookmarkDialog::CNewBookmarkDialog(wxWindow* parent, COptionsBase & options, std::wstring& site_path, Site const* site)
 	: m_parent(parent)
 	, options_(options)
 	, m_site_path(site_path)
 	, site_(site)
+	, impl_(std::make_unique<impl>())
+{
+}
+
+CNewBookmarkDialog::~CNewBookmarkDialog()
 {
 }
 
 int CNewBookmarkDialog::Run(wxString const& local_path, CServerPath const& remote_path)
 {
-	if (!Load(m_parent, _T("ID_NEWBOOKMARK"))) {
+	if (!Create(m_parent, nullID, _("New bookmark"))) {
 		return wxID_CANCEL;
 	}
 
-	xrc_call(*this, "ID_LOCALPATH", &wxTextCtrl::ChangeValue, local_path);
-	if (!remote_path.empty()) {
-		xrc_call(*this, "ID_REMOTEPATH", &wxTextCtrl::ChangeValue, remote_path.GetPath());
+	auto & lay = layout();
+	auto main = lay.createMain(this, 1);
+
+	{
+		auto [box, inner] = lay.createStatBox(main, _("Type"), 2);
+		impl_->global_ = new wxRadioButton(box, nullID, _("&Global bookmark"), wxDefaultPosition, wxDefaultSize, wxRB_GROUP);
+		inner->Add(impl_->global_);
+		impl_->global_->SetValue(1);
+		impl_->specific_ = new wxRadioButton(box, nullID, _("&Site-specific bookmark"));
+		inner->Add(impl_->specific_);
+		if (!site_) {
+			impl_->specific_->Disable();
+		}
+	}
+	{
+		auto [box, inner] = lay.createStatBox(main, _("Name"), 2);
+		inner->AddGrowableCol(1);
+		inner->Add(new wxStaticText(box, nullID, _("&Name")), lay.valign);
+		impl_->name_ = new wxTextCtrlEx(box, nullID);
+		inner->Add(impl_->name_, lay.valigng);
+	}
+	{
+		auto [box, inner] = lay.createStatBox(main, _("Paths"), 1);
+		inner->AddGrowableCol(0);
+		auto flex = lay.createFlex(2);
+		inner->Add(flex, lay.grow);
+		flex->Add(new wxStaticText(box, nullID, _("&Local directory:")), lay.valign);
+		flex->AddGrowableCol(1);
+		auto row = lay.createFlex(2);
+		row->AddGrowableCol(0);
+		flex->Add(row, lay.grow);
+		impl_->local_path_ = new wxTextCtrlEx(box, nullID, local_path);
+		row->Add(impl_->local_path_, lay.valigng);
+		auto browse = new wxButton(box, nullID, _("&Browse..."));
+		browse->Bind(wxEVT_BUTTON, [&](wxCommandEvent&){ OnBrowse(); });
+		row->Add(browse, lay.valign);
+
+		flex->Add(new wxStaticText(box, nullID, _("&Remote directory:")), lay.valign);
+		impl_->remote_path_ = new wxTextCtrlEx(box, nullID, remote_path.GetPath());
+		flex->Add(impl_->remote_path_, lay.valigng);
+
+		impl_->sync_browse_ = new wxCheckBox(box, nullID, _("Use &synchronized browsing"));
+		inner->Add(impl_->sync_browse_);
+		impl_->comparison_ = new wxCheckBox(box, nullID, _("D&irectory comparison"));
+		inner->Add(impl_->comparison_);
 	}
 
-	if (!site_) {
-		xrc_call(*this, "ID_TYPE_SITE", &wxRadioButton::Enable, false);
-	}
+	auto [buttons, ok, cancel] = lay.createButtonSizerButtons(this, main, false);
+	ok->Bind(wxEVT_BUTTON, [&](wxCommandEvent&) { OnOK(); });
+
+	GetSizer()->Fit(this);
 
 	return ShowModal();
 }
 
-void CNewBookmarkDialog::OnOK(wxCommandEvent&)
+void CNewBookmarkDialog::OnOK()
 {
-	bool const global = xrc_call(*this, "ID_TYPE_GLOBAL", &wxRadioButton::GetValue);
+	bool const global = impl_->global_->GetValue();
 
-	wxString const name = xrc_call(*this, "ID_NAME", &wxTextCtrl::GetValue);
+	wxString const name = impl_->name_->GetValue();
 	if (name.empty()) {
 		wxMessageBoxEx(_("You need to enter a name for the bookmark."), _("New bookmark"), wxICON_EXCLAMATION, this);
+		impl_->name_->SetFocus();
 		return;
 	}
 
-	wxString const local_path = xrc_call(*this, "ID_LOCALPATH", &wxTextCtrl::GetValue);
-	wxString remote_path_raw = xrc_call(*this, "ID_REMOTEPATH", &wxTextCtrl::GetValue);
+	wxString const local_path = impl_->local_path_->GetValue();
+	wxString remote_path_raw = impl_->remote_path_->GetValue();
 
 	CServerPath remote_path;
 	if (!remote_path_raw.empty()) {
@@ -86,13 +143,13 @@ void CNewBookmarkDialog::OnOK(wxCommandEvent&)
 		return;
 	}
 
-	bool const sync = xrc_call(*this, "ID_SYNC", &wxCheckBox::GetValue);
+	bool const sync = impl_->sync_browse_->GetValue();
 	if (sync && (local_path.empty() || remote_path_raw.empty())) {
 		wxMessageBoxEx(_("You need to enter both a local and a remote path to enable synchronized browsing for this bookmark."), _("New bookmark"), wxICON_EXCLAMATION, this);
 		return;
 	}
 
-	bool const comparison = xrc_call(*this, "ID_COMPARISON", &wxCheckBox::GetValue);
+	bool const comparison = impl_->comparison_->GetValue();
 
 	if (!global && site_) {
 		std::unique_ptr<Site> site;
@@ -133,13 +190,11 @@ void CNewBookmarkDialog::OnOK(wxCommandEvent&)
 	}
 }
 
-void CNewBookmarkDialog::OnBrowse(wxCommandEvent&)
+void CNewBookmarkDialog::OnBrowse()
 {
-	wxTextCtrl *const pText = XRCCTRL(*this, "ID_LOCALPATH", wxTextCtrl);
-
-	wxDirDialog dlg(this, _("Choose the local directory"), pText->GetValue(), wxDD_NEW_DIR_BUTTON);
+	wxDirDialog dlg(this, _("Choose the local directory"), impl_->local_path_->GetValue(), wxDD_NEW_DIR_BUTTON);
 	if (dlg.ShowModal() == wxID_OK) {
-		pText->ChangeValue(dlg.GetPath());
+		impl_->local_path_->ChangeValue(dlg.GetPath());
 	}
 }
 
