@@ -1,21 +1,27 @@
 #ifndef FILEZILLA_INTERFACE_OPTIONSPAGE_EDIT_HEADER
 #define FILEZILLA_INTERFACE_OPTIONSPAGE_EDIT_HEADER
 
+#include "optionspage.h"
+
+#include <memory>
+
 class COptionsPageEdit final : public COptionsPage
 {
 public:
-	virtual wxString GetResourceName() const override { return _T("ID_SETTINGS_EDIT"); }
+	COptionsPageEdit();
+	virtual ~COptionsPageEdit();
+
+	virtual bool CreateControls(wxWindow* parent) override;
 	virtual bool LoadPage() override;
 	virtual bool SavePage() override;
 	virtual bool Validate() override;
 
-protected:
+private:
+	struct impl;
+	std::unique_ptr<impl> impl_;
 
 	void SetCtrlState();
-
-	DECLARE_EVENT_TABLE()
-	void OnBrowseEditor(wxCommandEvent& event);
-	void OnRadioButton(wxCommandEvent& event);
+	void OnBrowseEditor();
 };
 
 #endif
