@@ -591,7 +591,10 @@ void ConfirmInsecureConection(wxWindow* parent, cert_store & certStore, CInsecur
 		name = CServer::GetProtocolName(protocol);
 		break;
 	}
-	dlg.Create(parent, nullID, wxString::Format(_("Insecure %s connection"), name));
+
+	if (!dlg.Create(parent, nullID, wxString::Format(_("Insecure %s connection"), name))) {
+		return;
+	}
 
 	auto const& lay = dlg.layout();
 	auto main = lay.createMain(&dlg, 1);
@@ -668,11 +671,13 @@ void ConfirmFtpTlsNoResumptionNotification(wxWindow* parent, cert_store & certSt
 {
 	wxDialogEx dlg;
 
-	dlg.Create(parent, nullID, _("Insecure FTP data connection"));
+	if (!dlg.Create(parent, nullID, _("Insecure FTP data connection"))) {
+		return;
+	}
 
 	auto const& lay = dlg.layout();
 	auto main = lay.createMain(&dlg, 1);
-	
+
 	auto v = certStore.GetSessionResumptionSupport(fz::to_utf8(notification.server_.GetHost()), notification.server_.GetPort());
 	bool const warning = v && *v;
 
