@@ -912,8 +912,6 @@ struct fxp_xfer {
     bool eof, err;
     struct fxp_handle *fh;
     struct req *head, *tail;
-    _fztimer send_timer;
-    int sent_interval;
 };
 
 static struct fxp_xfer *xfer_init(struct fxp_handle *fh, uint64_t offset)
@@ -928,8 +926,6 @@ static struct fxp_xfer *xfer_init(struct fxp_handle *fh, uint64_t offset)
     xfer->err = false;
     xfer->filesize = UINT64_MAX;
     xfer->furthestdata = 0;
-    fz_timer_init(&xfer->send_timer);
-    xfer->sent_interval = 0;
 
     return xfer;
 }
@@ -1208,12 +1204,6 @@ int xfer_upload_gotpkt(struct fxp_xfer *xfer, struct sftp_packet *pktin)
     else
         xfer->tail = prev;
     xfer->req_totalsize -= rr->len;
-    xfer->sent_interval += rr->len;
-    if (fz_timer_check(&xfer->send_timer)) {
-        /* The data we sent is the data we earlier read from file */
-        fzprintf(sftpTransfer, "%d", xfer->sent_interval);
-        xfer->sent_interval = 0;
-    }
     sfree(rr);
 
     if (!ret)
@@ -1224,10 +1214,6 @@ int xfer_upload_gotpkt(struct fxp_xfer *xfer, struct sftp_packet *pktin)
 
 void xfer_cleanup(struct fxp_xfer *xfer)
 {
-    if (xfer->sent_interval > 0) {
-        fzprintf(sftpTransfer, "%d", xfer->sent_interval);
-    }
-
     struct req *rr;
     while (xfer->head) {
         rr = xfer->head;
