@@ -197,7 +197,7 @@ int read_from_file(RFile *f, void *buffer, int length)
 #if 1
     if (f->state == ok && !f->remaining_) {
         fznotify1(sftp_io_nextbuf, 0);
-        char const* s = priority_read();
+        char * s = priority_read();
         if (s[1] == '-') {
             f->state = error;
             return -1;
@@ -206,7 +206,7 @@ int read_from_file(RFile *f, void *buffer, int length)
             f->state = eof;
         }
         else {
-            char const* p = s + 1;
+            char * p = s + 1;
             f->buffer_ = f->memory_ + next_int(&p);
             f->remaining_ = (int)next_int(&p);
         }
@@ -383,7 +383,7 @@ int write_to_file(WFile *f, void *buffer, int length)
 #if 1
     if (f->state == ok && !f->remaining_) {
         fznotify1(sftp_io_nextbuf, f->size_ - f->remaining_);
-        char const* s = priority_read();
+        char * s = priority_read();
         if (s[1] == '-') {
             f->state = error;
             return -1;
@@ -392,7 +392,7 @@ int write_to_file(WFile *f, void *buffer, int length)
             f->state = eof;
         }
         else {
-            char const* p = s + 1;
+            char * p = s + 1;
             f->buffer_ = f->memory_ + next_int(&p);
             f->remaining_ = (int)next_int(&p);
             f->size_ = f->remaining_;
